#############################################################
 # 
 # FILE:        UserAlloc.py
 # DATE:        5/21/2024
 # COMPANY:     BitFlow, Inc.
 # DESCRIPTION: A simple example of capturing data 
 #              in to a user allocated buffer array from a single frame grabber 
 #              board.
 #
#############################################################

import platform

if(platform.system() == 'Windows'):
    import sys
    import msvcrt

    if (sys.version_info.major >= 3 and sys.version_info.minor >= 8):
        import os
        #Following lines specifying, the location of DLLs, are required for Python Versions 3.8 and greater
        os.add_dll_directory(r"C:\BitFlow SDK 6.6\Bin64")
        os.add_dll_directory(r"C:\Program Files\CameraLink\Serial")

import numpy as np

import BFModule.BufferAcquisition as Buf
import BFModule.Display as Disp

def main():

    #Open Board
    CirAq = Buf.clsCircularAcquisition()
    CirAq.Open()

    #Get image parameters from the board
    xsize = CirAq.GetBoardInfo(Buf.InquireParams.XSize)
    ysize = CirAq.GetBoardInfo(Buf.InquireParams.YSize)
    bpp = CirAq.GetBoardInfo(Buf.InquireParams.BytesPerPix)

    #Number of Buffers to allocate
    NumBuffers = 10 

    #Initialize the buffer array
    BufArray = np.zeros([NumBuffers, ysize, xsize], dtype=np.uint8, order="C")

    #Buffer Setup using the user allocated buffer array
    b = CirAq.BufferSetupUser(BufArray, NumBuffers)
    CirAq.AqSetup(0)

    #Setup display window
    display = Disp.clsDisp(CirAq)
    display.Open()

    #Start Acquisition
    CirAq.AqControl(Buf.AcqCommands.Start, Buf.AcqControlOptions.Wait)

    try:
        while(1):
            try:
                CurBuf = CirAq.WaitForFrame(1000)
                if(display.isOpen):
                    display.Update(b[CurBuf.BufferNumber])
            except Exception as e:
                print(e)
    except KeyboardInterrupt:
        display.Close()
        pass

    #Stop Acquisition
    CirAq.AqControl(Buf.AcqCommands.Stop, Buf.AcqControlOptions.Wait)

    #Get and print capture stats
    capStats = CirAq.GetCaptureStatus()

    print("Capture Stats:")
    print("Captured: ", capStats[0])
    print("Missed: ", capStats[1])
    print('\n')

    #Cleanup and close
    CirAq.BufferCleanup()
    CirAq.Close()

if __name__ == "__main__":
    main()